@@ -11,7 +11,8 @@ class SendDataController:
         pass
     def sendDataInQueue(self, sender, processedCoT, clientInformationQueue, shareDataPipe = None):
         try:
-            print('sending data to fts client' + str(processedCoT.xmlString))
+            pass
+            # print('sending data to fts client' + str(processedCoT.xmlString))
         except Exception as e:
             print(e)
         try:
@@ -47,11 +48,11 @@ class SendDataController:
     def send_to_specific_client(self, clientInformationQueue, processedCoT, sender, shareDataPipe):
         try:
             if processedCoT.martiPresent == False:
-                print('marti not present')
+                # print('marti not present')
                 return self.send_to_all(clientInformationQueue, processedCoT, sender, shareDataPipe)
 
             else:
-                print('marti present')
+                # print('marti present')
                 for dest in processedCoT.modelObject.detail.marti.dest:
                     try:
                         for client in clientInformationQueue:
@@ -86,10 +87,10 @@ class SendDataController:
                 sock = client.socket
                 try:
                     if hasattr(processedCoT, 'xmlString'):
-                        print('sending to all ' + str(processedCoT.xmlString))
+                        # print('sending to all ' + str(processedCoT.xmlString))
                         sock.send(processedCoT.xmlString)
                     else:
-                        sock.send(processedCoT.idData.encode())
+                        sock.send(processedCoT.idData)
                 except Exception as e:
                     print(e)
                     logger.error('error in sending of data ' + str(processedCoT.xmlString))
