@@ -9,7 +9,7 @@ class MainConfig:
     should need to be changed
     """
     # this is the port to which clients will connect
-    CoTServicePort = int(8087)
+    CoTServicePort = int(15777)
 
     SSLCoTServicePort = int(8089)
 
@@ -42,10 +42,10 @@ class MainConfig:
     SaveCoTToDB = bool(True)
 
     # this should be set before startup
-    DBFilePath = str(r'/root/FTSDataBase.db')
+    DBFilePath = str(r'/opt/FTSDataBase.db')
 
     # the version information of the server (recommended to leave as default)
-    version = 'FreeTAKServer-1.5.8 RC 1'
+    version = 'FreeTAKServer-1.7 RC 1 Beta'
 
     MainPath = str(Path(fr'{userpath}{python_version}/dist-packages/FreeTAKServer'))
 
