@@ -17,7 +17,6 @@ from FreeTAKServer.controllers.services.SSLCoTServiceController import SSLCoTSer
 from FreeTAKServer.controllers.services.TCPCoTServiceController import TCPCoTServiceController
 from FreeTAKServer.controllers.services.federation.FederationClientService import FederationClientServiceController
 from FreeTAKServer.controllers.services.federation.federation import FederationServerService
-from FreeTAKServer.controllers.services.FederationServerServiceController import FederationServerServiceController
 from FreeTAKServer.controllers.DatabaseControllers.DatabaseController import DatabaseController
 from FreeTAKServer.controllers.certificate_generation import AtakOfTheCerts
 
@@ -528,7 +527,8 @@ class FTS:
                     # this runs in all other cases in which data is received
                     elif data != 0 and data is not None:
                         try:
-                            print('data received in FTS ' + str(data.xmlString))
+                            pass
+                            # print('data received in FTS ' + str(data.xmlString))
                         except:
                             pass
                         AddDataToCoTList().send(self.FilterGroup.receivers, data)
@@ -542,6 +542,7 @@ class FTS:
 
     def startup(self, CoTPort, CoTIP, DataPackagePort, DataPackageIP, SSLDataPackagePort, SSLDataPackageIP, RestAPIPort, RestAPIIP, SSLCoTPort, SSLCoTIP, AutoStart, firstStart = False, UI="False"):
         try:
+            self.dbController.remove_user()
             self.FTSServiceStartupConfigObject.RestAPIService.RestAPIServiceStatus = 'start'
             self.FTSServiceStartupConfigObject.RestAPIService.RestAPIServicePort = RestAPIPort
             self.FTSServiceStartupConfigObject.RestAPIServiceIP = RestAPIIP
